@@ -20,10 +20,12 @@ class PipelineOperator:
     CONTAINTER_NAME = ""
     CONNECTION_STRING_NAME = 'STORAGE_CONNECTION_STRING'
 
-    def __init__(self, conn_str: str, storage_url: str, container_name: str, map_file_name: str):
+    def __init__(self, conn_str: str, storage_url: str, container_name: str, map_file_name=f"storage_map_{datetime.now().strftime('%Y_%m')}.json"):
         self.logger = logging.getLogger(__name__)
         logging.basicConfig(level=logging.INFO)
         self.OUTPUT_NAME_JSON = map_file_name
+        if '.json' not in self.OUTPUT_NAME_JSON:
+            self.OUTPUT_NAME_JSON += ".json"
         self.OUTPUT_NAME_CSV = map_file_name.replace('json', 'csv')
         self.CONTAINTER_NAME = container_name
         conn_str = self._check_conn_str(
